@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,8 +25,7 @@
 #include "constants.h"
 
 About::About(QWidget *parent)
-    : QDialog(parent),
-      m_lang("en")
+    : QDialog(parent)
 {
     ui.setupUi(this);
     retranslateUi();
