@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,11 +29,9 @@ class About : public QDialog
 public:
     About(QWidget *parent = nullptr);
     void retranslateUi();
-    void setLanguage(const QString lang) { m_lang = lang; }
 
 private:
     Ui::AboutClass ui;
-    QString m_lang;
 };
 
 #endif // ABOUT_H
