@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -100,7 +100,11 @@ void VMPKKeyboardMap::initializeFromXML(QIODevice *dev)
                                 if (ok) insert(keycode, note);
                             } else {
                                 QKeySequence ks(key);
+							#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
                                 insert(ks[0], note);
+							#else
+								insert(ks[0].key(), note);
+							#endif
                             }
                         }
                     }
