@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -71,7 +71,11 @@ void KMapDialog::updateMap()
                 if (ok) m_map.insert(keycode, i);
             } else {
                 QKeySequence ks(item->text());
+			#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
                 m_map.insert(ks[0], i);
+			#else
+				m_map.insert(ks[0].key(), i);
+			#endif
             }
         }
     }
