@@ -40,6 +40,7 @@
 #include <QShortcut>
 #include <QActionGroup>
 #include <QStandardPaths>
+#include <QTimer>
 
 #include <drumstick/backendmanager.h>
 #include <drumstick/rtmidiinput.h>
@@ -132,6 +133,7 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags )
     connect(ui.actionColorPalette, SIGNAL(triggered()), SLOT(slotColorPolicy()));
     connect(ui.actionColorScale, SIGNAL(toggled(bool)), SLOT(slotColorScale(bool)));
     connect(ui.actionWindowFrame, SIGNAL(toggled(bool)), SLOT(toggleWindowFrame(bool)));
+    connect(ui.actionOctave_Subscript_Designation, SIGNAL(toggled(bool)), SLOT(slotOctaveSubscript(bool)));
     connect(ui.actionLoad_Configuration, &QAction::triggered, this, &VPiano::slotLoadConfiguration);
     connect(ui.actionSave_Configuration, &QAction::triggered, this, &VPiano::slotSaveConfiguration);
     // Toolbars actions: toggle view
@@ -191,8 +193,10 @@ void VPiano::initialization()
         initExtraControllers();
         enforceMIDIChannelState();
         activateWindow();
+        checkBackends();
     } else {
-        qWarning() << "Unable to initialize all MIDI drivers. Terminating.";
+        qWarning() << "MIDI drivers are missing. Perhaps you need to set a DRUMSTICKRT environment variable?."
+                   << "Unable to initialize MIDI. Terminating.";
     }
 }
 
@@ -641,6 +645,8 @@ void VPiano::readSettings()
     }
     ui.pianokeybd->setLabelOrientation(VPianoSettings::instance()->namesOrientation());
     ui.pianokeybd->setLabelOctave(VPianoSettings::instance()->namesOctave());
+    ui.actionOctave_Subscript_Designation->setChecked(VPianoSettings::instance()->octaveSubscript());
+    ui.pianokeybd->setOctaveSubscript(VPianoSettings::instance()->octaveSubscript());
 
     bool savedShortcuts = VPianoSettings::instance()->savedShortcuts();
     QList<QAction *> actions = findChildren<QAction *> ();
@@ -1721,6 +1727,35 @@ void VPiano::setWidgetTip(QWidget* w, int val)
     QToolTip::showText(w->parentWidget()->mapToGlobal(w->pos()), tip);
 }
 
+void VPiano::checkBackends()
+{
+#if defined(Q_OS_LINUX)
+    const QString output{QLatin1String("SonivoxEAS")};
+#elif defined(Q_OS_MACOS)
+    const QString output{QLatin1String("DLS Synth")};
+#elif defined(Q_OS_WINDOWS)
+    const QString output{QLatin1String("Windows MM")};
+#elif defined(Q_OS_UNIX)
+    const QString output{QLatin1String("FluidSynth")};
+#else
+    const QString output{QLatin1String("Network")};;
+#endif
+
+    if (m_backendManager != nullptr) {
+        auto outs = m_backendManager->availableOutputs();
+        bool found = false;
+        foreach(const auto obj, outs) {
+            if (obj->backendName() == output) {
+                found = true;
+                break;
+            }
+        }
+        if (!found) {
+            QTimer::singleShot(1500, this, [=](){slotBackendTest(output);});
+        }
+    }
+}
+
 //void VPiano::slotEditPrograms()
 //{ }
 
@@ -2246,6 +2281,24 @@ void VPiano::slotSaveConfiguration()
     grabKb();
 }
 
+void VPiano::slotOctaveSubscript(bool value)
+{
+    //qDebug() << Q_FUNC_INFO << value;
+    VPianoSettings::instance()->setOctaveSubscript(value);
+    ui.pianokeybd->setOctaveSubscript(value);
+}
+
+void VPiano::slotBackendTest(const QString &name)
+{
+    //qDebug() << Q_FUNC_INFO << name;
+    QString msg = tr("The important component called '%1' is missing.\n"
+      "This probably means that your installation is corrupt, or "
+      "the 'drumstick' packages on which this program depends are "
+      "incomplete, outdated or wrong. You may still use the program, "
+      "but probably without sound.").arg(name);
+    QMessageBox::warning(this, tr("MIDI Output"), msg);
+}
+
 #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
 bool VPiano::nativeEvent(const QByteArray &eventType, void *message, long *result)
 #else
