@@ -1,6 +1,6 @@
 ﻿/*
  MIDI Virtual Piano Keyboard
- Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+ Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -39,7 +39,10 @@
 using namespace drumstick::rt;
 using namespace drumstick::widgets;
 
-VPianoSettings::VPianoSettings(QObject *parent) : QObject(parent)
+VPianoSettings::VPianoSettings(QObject *parent) : QObject(parent),
+    m_trq(nullptr),
+    m_trp(nullptr),
+    m_trl(nullptr)
 {
     ResetDefaults();
     initializePalettes();
@@ -119,7 +122,11 @@ QString VPianoSettings::systemLocales()
 #if defined(TRANSLATIONS_EMBEDDED)
     return QLatin1String(":/");
 #else
+#if QT_VERSION < QT_VERSION_CHECK(6,0,0)
     return QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+#else
+	return QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+#endif	
 #endif
 }
 
@@ -230,8 +237,12 @@ void VPianoSettings::internalRead(QSettings &settings)
     m_baseOctave = settings.value(QSTR_BASEOCTAVE, 1).toInt();
     m_transpose = settings.value(QSTR_TRANSPOSE, 0).toInt();
     m_numKeys = settings.value(QSTR_NUMKEYS, DEFAULTNUMBEROFKEYS).toInt();
-    setInstruments(settings.value(QSTR_INSTRUMENTSDEFINITION, QLatin1String(":/vpiano/") + QSTR_DEFAULTINS).toString(),
-        settings.value(QSTR_INSTRUMENTNAME).toString());
+    QString insFile = settings.value(QSTR_INSTRUMENTSDEFINITION).toString();
+    if (insFile.isEmpty()) {
+        insFile = QLatin1String(":/vpiano/") + QSTR_DEFAULTINS;
+    }
+    QString insName = settings.value(QSTR_INSTRUMENTNAME).toString();
+    setInstruments(insFile, insName);
     m_alwaysOnTop = settings.value(QSTR_ALWAYSONTOP, false).toBool();
     m_showStatusBar = settings.value(QSTR_SHOWSTATUSBAR, false).toBool();
     m_velocityColor = settings.value(QSTR_VELOCITYCOLOR, true).toBool();
@@ -243,7 +254,7 @@ void VPianoSettings::internalRead(QSettings &settings)
     m_startingKey = settings.value(QSTR_STARTINGKEY, DEFAULTSTARTINGKEY).toInt();
     m_highlightPaletteId = settings.value(QSTR_CURRENTPALETTE, PAL_SINGLE).toInt();
     m_colorScale = settings.value(QSTR_SHOWCOLORSCALE, false).toBool();
-    m_language = settings.value(QSTR_LANGUAGE, QLocale::system().name()).toString();
+    m_language = settings.value(QSTR_LANGUAGE).toString();
 #if defined(Q_OS_WINDOWS)
     m_winSnap = settings.value(QSTR_WINSNAP, true).toBool();
 #endif
@@ -272,11 +283,15 @@ void VPianoSettings::internalRead(QSettings &settings)
     QFont f;
     if (f.fromString(settings.value("namesFont", QSTR_DEFAULTFONT).toString())) {
         setNamesFont(f);
+    } else {
+        f.fromString(QApplication::font().family() + ",50");
+        setNamesFont(f);
     }
     setNamesOrientation(static_cast<LabelOrientation>(settings.value("namesOrientation", HorizontalOrientation).toInt()));
     setNamesVisibility(static_cast<LabelVisibility>(settings.value("namesVisibility", ShowNever).toInt()));
     setNamesAlterations(static_cast<LabelAlteration>(settings.value("namesAlteration", ShowSharps).toInt()));
     setNamesOctave(static_cast<LabelCentralOctave>(settings.value("namesOctave", OctaveC4).toInt()));
+    setOctaveSubscript(settings.value("octaveSubscript", true).toBool());
     settings.endGroup();
 
     emit ValuesChanged();
@@ -340,11 +355,12 @@ void VPianoSettings::internalSave(QSettings &settings)
     settings.endGroup();
 
     settings.beginGroup("TextSettings");
-    settings.setValue("namesFont", m_namesFont.toString());
+    settings.setValue("namesFont", fontString(m_namesFont));
     settings.setValue("namesOrientation", m_namesOrientation);
     settings.setValue("namesVisibility", m_namesVisibility);
     settings.setValue("namesAlteration", m_namesAlteration);
     settings.setValue("namesOctave", m_namesOctave);
+    settings.setValue("octaveSubscript", m_octaveSubscript);
     settings.endGroup();
 
     savePalettes();
@@ -720,11 +736,11 @@ void VPianoSettings::setInstruments( const QString fileName, const QString instr
                 m_insName = m_insList.first().instrumentName();
             }
         } else {
-            m_insFileName = QString();
-            m_insName = QString();
+            m_insFileName.clear();
+            m_insName.clear();
         }
     } else {
-        qWarning() << "file" << fileName << "not readable.";
+        qWarning() << "instruments definition file" << fileName << "not readable.";
     }
 }
 
@@ -810,6 +826,21 @@ void VPianoSettings::savePalettes()
     }
 }
 
+QString VPianoSettings::fontString(const QFont& f) const
+{
+    return QString("%1,%2").arg(f.family()).arg(f.pointSize());
+}
+
+bool VPianoSettings::octaveSubscript() const
+{
+    return m_octaveSubscript;
+}
+
+void VPianoSettings::setOctaveSubscript(bool newOctaveSubscript)
+{
+    m_octaveSubscript = newOctaveSubscript;
+}
+
 QString VPianoSettings::getStyle() const
 {
     return m_style;
@@ -820,6 +851,54 @@ void VPianoSettings::setStyle(const QString &style)
     m_style = style;
 }
 
+void VPianoSettings::loadTranslations()
+{
+    QLocale loc;
+    QString lang = VPianoSettings::instance()->language();
+    if (!lang.isEmpty()) {
+        loc = QLocale(lang);
+    }
+    if (m_trq) {
+        QCoreApplication::removeTranslator(m_trq);
+        delete m_trq;
+    }
+    if (m_trp) {
+        QCoreApplication::removeTranslator(m_trp);
+        delete m_trp;
+    }
+    if (m_trl) {
+        QCoreApplication::removeTranslator(m_trl);
+        delete m_trl;
+    }
+    if ((loc.language() != QLocale::C) && (loc.language() != QLocale::English)) {
+        m_trq = new QTranslator(this);
+        if (m_trq->load(loc, QSTR_QTPX, "_", VPianoSettings::systemLocales())) {
+            QCoreApplication::installTranslator(m_trq);
+        } else {
+            qWarning() << "Failure loading Qt system translations for" << lang
+                       << "from" << VPianoSettings::systemLocales();
+            delete m_trq;
+        }
+        m_trp = new QTranslator(this);
+        if (m_trp->load(loc, QSTR_VMPKPX, "_", VPianoSettings::localeDirectory())) {
+            QCoreApplication::installTranslator(m_trp);
+        } else {
+            qWarning() << "Failure loading VMPK application translations for" << lang
+                       << "from" << VPianoSettings::localeDirectory();
+            delete m_trp;
+        }
+        m_trl = new QTranslator(this);
+        if (m_trl->load(loc, QSTR_DRUMSTICKPX, "_", VPianoSettings::drumstickLocales())) {
+            QCoreApplication::installTranslator(m_trl);
+        } else {
+            qWarning() << "Failure loading widgets library translations for" << lang
+                       << "from" << VPianoSettings::drumstickLocales();
+            delete m_trl;
+        }
+    }
+    retranslatePalettes();
+}
+
 bool VPianoSettings::getDarkMode() const
 {
     return m_darkMode;
